==> certmanager-model-v1alpha2-6.4.1-sources.jar: io/fabric8/certmanager/api/model/acme/v1alpha2/OrderStatusFluent.java <==
package io.fabric8.certmanager.api.model.acme.v1alpha2;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface OrderStatusFluent<A extends OrderStatusFluent<A>> extends Fluent<A>{
  public A addToAuthorizations(Integer index,ACMEAuthorization item);
  public A setToAuthorizations(Integer index,ACMEAuthorization item);
  public A addToAuthorizations(io.fabric8.certmanager.api.model.acme.v1alpha2.ACMEAuthorization... items);
  public A addAllToAuthorizations(Collection<ACMEAuthorization> items);
  public A removeFromAuthorizations(io.fabric8.certmanager.api.model.acme.v1alpha2.ACMEAuthorization... items);
  public A removeAllFromAuthorizations(Collection<ACMEAuthorization> items);
  public A removeMatchingFromAuthorizations(Predicate<ACMEAuthorizationBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildAuthorizations instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<ACMEAuthorization> getAuthorizations();
  public List<ACMEAuthorization> buildAuthorizations();
  public ACMEAuthorization buildAuthorization(Integer index);
  public ACMEAuthorization buildFirstAuthorization();
  public ACMEAuthorization buildLastAuthorization();
  public ACMEAuthorization buildMatchingAuthorization(Predicate<ACMEAuthorizationBuilder> predicate);
  public Boolean hasMatchingAuthorization(Predicate<ACMEAuthorizationBuilder> predicate);
  public A withAuthorizations(List<ACMEAuthorization> authorizations);
  public A withAuthorizations(io.fabric8.certmanager.api.model.acme.v1alpha2.ACMEAuthorization... authorizations);
  public Boolean hasAuthorizations();
  public OrderStatusFluent.AuthorizationsNested<A> addNewAuthorization();
  public OrderStatusFluent.AuthorizationsNested<A> addNewAuthorizationLike(ACMEAuthorization item);
  public OrderStatusFluent.AuthorizationsNested<A> setNewAuthorizationLike(Integer index,ACMEAuthorization item);
  public OrderStatusFluent.AuthorizationsNested<A> editAuthorization(Integer index);
  public OrderStatusFluent.AuthorizationsNested<A> editFirstAuthorization();
  public OrderStatusFluent.AuthorizationsNested<A> editLastAuthorization();
  public OrderStatusFluent.AuthorizationsNested<A> editMatchingAuthorization(Predicate<ACMEAuthorizationBuilder> predicate);
  public String getCertificate();
  public A withCertificate(String certificate);
  public Boolean hasCertificate();
  public String getFailureTime();
  public A withFailureTime(String failureTime);
  public Boolean hasFailureTime();
  public String getFinalizeURL();
  public A withFinalizeURL(String finalizeURL);
  public Boolean hasFinalizeURL();
  public String getReason();
  public A withReason(String reason);
  public Boolean hasReason();
  public String getState();
  public A withState(String state);
  public Boolean hasState();
  public String getUrl();
  public A withUrl(String url);
  public Boolean hasUrl();
  public interface AuthorizationsNested<N> extends Nested<N>,ACMEAuthorizationFluent<OrderStatusFluent.AuthorizationsNested<N>>{
    public N and();
    public N endAuthorization();
    
  }
  
}

==> certmanager-model-v1alpha2-6.7.1-sources.jar: io/fabric8/certmanager/api/model/acme/v1alpha2/OrderStatusFluent.java <==
package io.fabric8.certmanager.api.model.acme.v1alpha2;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface OrderStatusFluent<A extends OrderStatusFluent<A>> extends Fluent<A>{
  public A addToAuthorizations(int index,ACMEAuthorization item);
  public A setToAuthorizations(int index,ACMEAuthorization item);
  public A addToAuthorizations(io.fabric8.certmanager.api.model.acme.v1alpha2.ACMEAuthorization... items);
  public A addAllToAuthorizations(Collection<ACMEAuthorization> items);
  public A removeFromAuthorizations(io.fabric8.certmanager.api.model.acme.v1alpha2.ACMEAuthorization... items);
  public A removeAllFromAuthorizations(Collection<ACMEAuthorization> items);
  public A removeMatchingFromAuthorizations(Predicate<ACMEAuthorizationBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildAuthorizations instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<ACMEAuthorization> getAuthorizations();
  public List<ACMEAuthorization> buildAuthorizations();
  public ACMEAuthorization buildAuthorization(int index);
  public ACMEAuthorization buildFirstAuthorization();
  public ACMEAuthorization buildLastAuthorization();
  public ACMEAuthorization buildMatchingAuthorization(Predicate<ACMEAuthorizationBuilder> predicate);
  public Boolean hasMatchingAuthorization(Predicate<ACMEAuthorizationBuilder> predicate);
  public A withAuthorizations(List<ACMEAuthorization> authorizations);
  public A withAuthorizations(io.fabric8.certmanager.api.model.acme.v1alpha2.ACMEAuthorization... authorizations);
  public Boolean hasAuthorizations();
  public OrderStatusFluent.AuthorizationsNested<A> addNewAuthorization();
  public OrderStatusFluent.AuthorizationsNested<A> addNewAuthorizationLike(ACMEAuthorization item);
  public OrderStatusFluent.AuthorizationsNested<A> setNewAuthorizationLike(int index,ACMEAuthorization item);
  public OrderStatusFluent.AuthorizationsNested<A> editAuthorization(int index);
  public OrderStatusFluent.AuthorizationsNested<A> editFirstAuthorization();
  public OrderStatusFluent.AuthorizationsNested<A> editLastAuthorization();
  public OrderStatusFluent.AuthorizationsNested<A> editMatchingAuthorization(Predicate<ACMEAuthorizationBuilder> predicate);
  public String getCertificate();
  public A withCertificate(String certificate);
  public Boolean hasCertificate();
  public String getFailureTime();
  public A withFailureTime(String failureTime);
  public Boolean hasFailureTime();
  public String getFinalizeURL();
  public A withFinalizeURL(String finalizeURL);
  public Boolean hasFinalizeURL();
  public String getReason();
  public A withReason(String reason);
  public Boolean hasReason();
  public String getState();
  public A withState(String state);
  public Boolean hasState();
  public String getUrl();
  public A withUrl(String url);
  public Boolean hasUrl();
  public interface AuthorizationsNested<N> extends Nested<N>,ACMEAuthorizationFluent<OrderStatusFluent.AuthorizationsNested<N>>{
    public N and();
    public N endAuthorization();
    
  }
  
}
